#pragma once
#include <string>

/// <summary>
/// Describes a checker board position
/// </summary>
class CheckerPosition {
public:
    int x, y;

    /// <summary>
    /// Create the position by its X and Y coordinates
    /// </summary>
    /// <param name="x">X coordinate</param>
    /// <param name="y">Y coordinate</param>
    CheckerPosition(int x, int y);

    /// <summary>
    /// Create the position by its text representation (eg "A1")
    /// </summary>
    /// <param name="pos">The position's text representation</param>
    CheckerPosition(std::string pos);

    /// <summary>
    /// Get the text representation of the current position
    /// </summary>
    /// <returns>Text representation of the position</returns>
    std::string to_string() const;

    /// <summary>
    /// Get the number representation of the current position
    /// </summary>
    /// <returns>Number representation of the position</returns>
    std::string to_num_string() const;

    /// <summary>
    /// Whether or not the given position is a valid checker position
    /// </summary>
    /// <returns>True if the position is valid</returns>
    bool isValid() const;
};