#pragma once
#include "CheckerBoard.h"


class CheckersAI {
public:
    CheckersAI(bool isWhite) : isWhite(isWhite) {}

    /// <summary>
    /// Find best possible move on the given board
    /// </summary>
    /// <param name="board">The board setup</param>
    /// <param name="depth">Minimax search depth</param>
    /// <returns>Updated board</returns>
    CheckerBoard findBestMove(const CheckerBoard& board, int depth);

private:
    bool isWhite;

    /// <summary>
    /// Recursively find best performing move
    /// </summary>
    /// <param name="board">The board setup</param>
    /// <param name="depth">Search depth</param>
    /// <param name="alpha">Alpha value</param>
    /// <param name="beta">Beta value</param>
    /// <param name="isMaximizing">Seek for maximum value, otherwise seek for minimum</param>
    /// <returns>Evaluated score</returns>
    int minimax(CheckerBoard board, int depth, int alpha, int beta, bool isMaximizing);
};